@@ -3,7 +3,7 @@ import urllib.parse
 import urllib.request
 
 class wechat():
-    def __init_(self, _url):
+    def __init__(self, _url):
         self.url = _url
 
     def sendMsg(self, _msg, _debugMode=False):
